#' Split a string based on CamelCase
#'
#' See [strex::str_split_camel_case()].
#'
#' @inheritParams strex::str_split_camel_case
#'
#' @export
str_split_camel_case <- strex::str_split_camel_case

#' @rdname str_split_camel_case
#' @export
split_camel_case <- str_split_camel_case
